==> react-native-ui-xep-0.1.21.tgz: package/src/atoms/select/Select.tsx <==
import React, { FC } from 'react';
// import { Picker } from '@react-native-community/picker';
// import { PickerProps } from '@react-native-community/picker/typings/Picker';
import { styles } from './styles';
import {
  Icon,
  Item,
  Label,
  NativeBase,
  Picker,
  RnViewStyleProp,
  Text,
} from 'native-base';
import * as ReactNative from 'react-native';

export type SelectProps = NativeBase.Picker & {
  type?: 'material' | 'custom' | 'bordered';
  pickerProps?: ReactNative.PickerItemProps;
  pickerList: [{ value: string; label: string }];
  selectStyle?: any;
  labelProps?: NativeBase.Label;
  selectProps?: NativeBase.Input;
  label?: string;
  style?: RnViewStyleProp;
  validationInfo?: string[];
};
export const Select: FC<SelectProps> = (props: SelectProps) => {
  const {
    selectStyle,
    validationInfo,
    label,
    style,
    labelProps,
    type,
    pickerList,
    pickerProps,
  } = props;
  const propsX = props;
  delete propsX.style;
  const renderElement = (selectStyleX?: any, labelStyle?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <Item style={selectStyleX} picker>
          <Picker
            iosIcon={<Icon color={'white'} name="arrow-down" />}
            // placeholderStyle={{color: 'red'}}
            note
            mode="dialog"
            {...propsX}
            style={
              selectStyle ? { ...selectStyleX, ...selectStyle } : selectStyleX
            }
          >
            {pickerList.map((item, index) => {
              return (
                <Picker.Item
                  key={index}
                  label={item.label}
                  value={item.value}
                  {...pickerProps}
                />
              );
            })}
          </Picker>
        </Item>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'bordered':
      return renderElement(styles.bordered, {
        ...styles.textDefault,
        color: '#979797',
      });
    default:
      return renderElement(styles.default, styles.textDefault);
  }
};

==> react-native-ui-xep-0.1.25.tgz: package/src/atoms/select/Select.tsx <==
import React, { FC } from 'react';
// import { Picker } from '@react-native-community/picker';
// import { PickerProps } from '@react-native-community/picker/typings/Picker';
import { styles } from './styles';
import {
  Icon,
  Item,
  Label,
  NativeBase,
  Picker,
  RnViewStyleProp,
  Text,
} from 'native-base';
import * as ReactNative from 'react-native';
import { Platform } from 'react-native';

export type SelectProps = NativeBase.Picker & {
  type?: 'material' | 'custom' | 'bordered' | 'material-black';
  pickerProps?: ReactNative.PickerItemProps;
  pickerList: [{ value: string; label: string }];
  selectStyle?: any;
  labelProps?: NativeBase.Label;
  selectProps?: NativeBase.Input;
  label?: string;
  style?: RnViewStyleProp;
  validationInfo?: string[];
};
export const Select: FC<SelectProps> = (props: SelectProps) => {
  const {
    selectStyle,
    validationInfo,
    label,
    style,
    labelProps,
    type,
    pickerList,
    pickerProps,
  } = props;
  const propsX = props;
  delete propsX.style;
  const renderElement = (selectStyleX?: any, labelStyle?: any) => {
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        <Item style={selectStyleX} picker>
          <Picker
            iosIcon={<Icon color={'white'} name="arrow-down" />}
            // placeholderStyle={{color: 'red'}}
            note
            mode="dialog"
            {...propsX}
            style={selectStyle}
          >
            {pickerList.map((item, index) => {
              return (
                <Picker.Item
                  key={index}
                  label={item.label}
                  value={item.value}
                  {...pickerProps}
                />
              );
            })}
          </Picker>
        </Item>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'bordered':
      return renderElement(styles.bordered, {
        ...styles.textDefault,
        color: '#979797',
      });
    case 'material-black':
      return renderElement(
        [styles.material, { color: 'black', borderColor: 'black' }],
        {
          ...styles.textDefault,
          color: 'black',
        }
      );
    default:
      return renderElement(styles.default, styles.textDefault);
  }
};
